release-plz 0.3.0

Update version and changelog based on semantic versioning and conventional commits
release-plz-0.3.0 is not a library.

release-plz-logo

Crates.io CI Docker

Release-plz updates the versions and changelogs of your rust packages, by analyzing your git history, based on conventional commits:

  • release-plz update updates your project locally, without committing any change.
  • release-plz release-pr opens a GitHub Pull Request.

Once the changes are merged to the main branch, you can use release-plz release to publish the new versions of the packages.

Here's an example of a release Pull Request created on the release-plz repository itself:

pr

Docs

Learn how to use release-plz in the mdbook docs.

Users

This GitHub search shows the public repositories using release-plz in CI.

Similar projects

  • release-please: release-plz is inspired by release-please, but instead of determining the next versions based on git tags, release-plz compares local packages with the ones published in the cargo registry. Plus, release-plz doesn't need any configuration.
  • cargo smart-release: Fearlessly release workspace crates and with beautiful semi-handcrafted changelogs.

Credits

Parts of the codebase are inspired by: